Weld.SmokeApp (weld v0.7.2)

Copy Markdown View Source

Generates a temporary smoke app that depends on the welded package by local path and compiles it.

Summary

Functions

verify!(plan, build_path)

@spec verify!(Weld.Plan.t(), Path.t()) :: map()