Generates a temporary smoke app that depends on the welded package by local path and compiles it.
Summary
Functions
@spec verify!(Weld.Plan.t(), Path.t()) :: map()
Generates a temporary smoke app that depends on the welded package by local path and compiles it.
@spec verify!(Weld.Plan.t(), Path.t()) :: map()